@@ -354,7 +354,7 @@ def get_table_meta(
         if col[1].name not in skip:
             if col[1].name == "DB_TYPE_NUMBER":
                 if col[4] == 0 and col[5] == -127:
-                    column_type = "int"
+                    column_type = "decimal(38,10)"
                 else:
                     column_type = f"decimal({col[4]},{col[5]})"
             else:
